Predict cophescan hypothesis for tested associations
Source:R/cophe_hyp_predict.R
cophe.hyp.predict.RdPredict cophescan hypothesis for tested associations
Usage
cophe.hyp.predict(
cophe.res,
grouping.vars = c("querysnp", "querytrait"),
Hc.cutoff = 0.6,
Hn.cutoff = 0.2
)Arguments
- cophe.res
results obtained from
cophe.single,cophe.susieorcophe.multitraitor data.frame with the following columns: PP.Hn, PP.Hc, PP.Ha, querysnp, querytrait- grouping.vars
This is important for results from
cophe.susiewhere there are multiple signals. These will be collapsed into one call. If you want to return all signals set this to a single variable eg: grouping.vars = c('querysnp')- Hc.cutoff
threshold for PP.Hc above which the associations are called Hc
- Hn.cutoff
threshold for PP.Hn above which the associations are called Hn
Value
returns dataframe with posterior probabilties of Hn, Hc and Ha with the predicted hypothesis based on the provided cut.offs.