Learn R Programming

cophescan (version 1.4.2)

get_posterior_prob: Calculation of the posterior prob of Hn, Ha and Hc

Description

Calculation of the posterior prob of Hn, Ha and Hc

Usage

get_posterior_prob(params, lbf_mat, nsnps, covar_vec, covar = FALSE)

Value

posterior prob of Hn, Ha and Hc

Arguments

params

Vector of parameters: \(\alpha\), \(\beta\) and \(\gamma\)

lbf_mat

matrix of log bayes factors: lBF.Ha and lBF.Hc

nsnps

number of snps

covar_vec

Vector of the covariate

covar

logical: should the covariate inflormation be used? default: False