Learn R Programming

cophescan (version 1.4.2)

hypothesis.priors: hypothesis.priors

Description

Estimate priors for each hypothesis

Usage

hypothesis.priors(nsnps, pn, pa, pc)

Value

hypotheses priors

Arguments

nsnps

number of SNPs

pn

prior probability that none of the SNPs/variants in the region are associated with the query trait

pa

prior probability that a non-query variant is causally associated with the query trait

pc

prior probability that the query variant is causally associated with the query trait

Author

Ichcha Manipur