cophe.prepare.dat.susie: Prepare data for cophe.susie
Description
Prepare data for cophe.susie
Usage
cophe.prepare.dat.susie(dataset, querysnpid, susie.args)
Value
a list with the output of running susie
Arguments
- dataset
a list with specifically named elements defining the query trait dataset
to be analysed.
- querysnpid
Id of the query variant, (id in dataset$snp)
- susie.args
a named list of additional arguments to be passed to
runsusie