- dataset
either a list with specifically named elements defining the dataset
to be analysed. (see
check_dataset)
- querysnpid
Id of the query variant
- querytrait
Query trait name
- pa
prior probability that a non-query variant is causally associated with the query trait (cophescan prior), default 3.82e-5
- pc
prior probability that the query variant is causally associated with the query trait (cophescan prior), default 1.82e-3
- p1
prior probability a SNP is associated with trait 1, (coloc prior), pc derived by using \(pc = p12/p1+p12\); use p1, p2, p12 only when pa and pc are unavailable (See vignettes)
- p2
prior probability a SNP is associated with trait 2, (coloc prior), pa derived by using \(pa = p2\)
- p12
prior probability a SNP is associated with both traits, (coloc prior), pc derived by using \(pc = p12/p1+p12\)
- susie.args
a named list of additional arguments to be passed to
runsusie