Heatmap of multi-trait cophescan results
cophe_heatmap(
multi.dat,
querysnpid,
query_trait_names,
thresh_Hc = 0.5,
thresh_Ha = 0.5,
...
)heatmap of posterior probabilities of the phentypes above the set threshold
multi trait cophescan results returned from cophe.multitrait or formatted in the same way with multitrait.simplify
query variant
names of phenotypes corresponding to the multi.dat results
Hc threshold to be displayed
Ha threshold to be displayed
additional arguments to be passed to pheatmap